@@ -2,25 +2,25 @@
 #
 # Copyright, 2006, by Paul McGuire
 #
-
+from __future__ import print_function
 from pyparsing import *
 
+
 cvtBool = lambda t:t[0]=='True'
 cvtInt = lambda toks: int(toks[0])
 cvtReal = lambda toks: float(toks[0])
 cvtTuple = lambda toks : tuple(toks.asList())
 cvtDict = lambda toks: dict(toks.asList())
+cvtList = lambda toks: [toks.asList()]
 
 # define punctuation as suppressed literals
 lparen,rparen,lbrack,rbrack,lbrace,rbrace,colon = \
     map(Suppress,"()[]{}:")
 
-integer = Combine(Optional(oneOf("+ -")) + Word(nums))\
+integer = Regex(r"[+-]?\d+")\
     .setName("integer")\
     .setParseAction( cvtInt )
-real = Combine(Optional(oneOf("+ -")) + Word(nums) + "." +
-               Optional(Word(nums)) +
-               Optional(oneOf("e E")+Optional(oneOf("+ -")) +Word(nums)))\
+real = Regex(r"[+-]?\d+\.\d*([Ee][+-]?\d+)?")\
     .setName("real")\
     .setParseAction( cvtReal )
 tupleStr = Forward()
@@ -41,6 +41,7 @@ tupleStr.setParseAction( cvtTuple )
 
 listStr << (lbrack + Optional(delimitedList(listItem) + 
             Optional(Suppress(","))) + rbrack)
+listStr.setParseAction(cvtList, lambda t: t[0])
 
 dictEntry = Group( listItem + colon + listItem )
 dictStr << (lbrace + Optional(delimitedList(dictEntry) + \
@@ -58,12 +59,12 @@ tests = """['a', 100, ('A', [101,102]), 3.14, [ +2.718, 'xyzzy', -1.414] ]
            'a quoted string'""".split("\n")
 
 for test in tests:
-    print "Test:", test.strip()
+    print("Test:", test.strip())
     result = listItem.parseString(test)[0]
-    print "Result:", result
+    print("Result:", result)
     try:
         for dd in result:
-            if isinstance(dd,dict): print dd.items()
-    except TypeError,te:
+            if isinstance(dd,dict): print(list(dd.items()))
+    except TypeError as te:
         pass
-    print
+    print()
